import React from "react";
import { Button } from "../../button";
import { PureComponent, createRef } from "react";
import { bool, func, string } from "prop-types";
import { isNil } from "lodash";
import { mergeClasses } from "../../shared";
export class DatePickerButtons extends PureComponent {
  constructor(...args) {
    super(...args);
    this._applyRef = /*#__PURE__*/createRef();

    this.handleClear = event => {
      const {
        canClear,
        onClear
      } = this.props;

      if (canClear) {
        onClear(event);
      } // Since clearing the date(s) will disabled the "clear" button we move the focus to the "apply" button.


      setTimeout(() => {
        if (!isNil(this._applyRef.current)) {
          this._applyRef.current.focus();
        }
      }, 0);
    };

    this.handleApply = event => {
      const {
        canApply,
        onApply
      } = this.props;

      if (canApply) {
        onApply(event);
      }
    };
  }

  renderClearButton() {
    const {
      canClear,
      allowClear,
      clearText
    } = this.props;

    if (!allowClear) {
      return null;
    } // Must used a CSS class to hide the button instead of conditional rendering otherwise clicking the button will be considered an outside click.


    return /*#__PURE__*/React.createElement(Button, {
      onClick: this.handleClear,
      ghost: true,
      compact: true,
      size: "small",
      disabled: !canClear,
      tabIndex: canClear ? "0" : "-1"
    }, clearText);
  }

  renderApplyButton() {
    const {
      canApply,
      applyText
    } = this.props;
    return /*#__PURE__*/React.createElement(Button, {
      onClick: this.handleApply,
      ghost: true,
      compact: true,
      primary: canApply,
      disabled: !canApply,
      size: "small",
      className: "ml-auto",
      tabIndex: canApply ? "0" : "-1",
      ref: this._applyRef
    }, applyText);
  }

  render() {
    const {
      className
    } = this.props;
    const classes = mergeClasses("flex ph6 pb6 pt1", className);
    return /*#__PURE__*/React.createElement("div", {
      className: classes
    }, this.renderClearButton(), this.renderApplyButton());
  }

}
DatePickerButtons.displayName = "DatePickerButtons";
DatePickerButtons.propTypes = {
  canClear: bool.isRequired,
  canApply: bool.isRequired,
  onClear: func,
  onApply: func,
  allowClear: bool,
  clearText: string,
  applyText: string,
  className: string
};
DatePickerButtons.defaultProps = {
  clearText: "Clear",
  applyText: "Apply"
};