import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from "react";
import { InlineSingleDatePickerInput } from "./inline-single-date-picker-input";
import { PureComponent } from "react";
import { SingleDatePicker } from "./single-date-picker";
import { SingleDatePickerButtons } from "./single-date-picker-buttons";
import { SingleDatePickerCalendar } from "./single-date-picker-calendar";
import { bool, element, func, number, oneOf, oneOfType, string } from "prop-types";
import { isNil } from "lodash";
import { momentObj as momentType } from "react-moment-proptypes"; // Duplicated here until https://github.com/reactjs/react-docgen/pull/352 is merged. Otherwise the props will not render properly in the docs.

const SINGLE_DATE_PICKER_PROP_TYPES = {
  /**
   * A controlled date value.
   */
  date: momentType,

  /**
   * The initial value of date.
   */
  defaultDate: momentType,

  /**
   * Called when the date is applied.
   * @param {SyntheticEvent} event - React's original SyntheticEvent.
   * @param {Moment} date - Selected date.
   * @returns {void}
   */
  onDateChange: func.isRequired,

  /**
   * Called when the calendar open / close.
   * Called when the calendar open / close.
   * @param {SyntheticEvent} event - React's original SyntheticEvent.
   * @param {boolean} isVisible - Indicate if the calendar is visible.
   * @returns {void}
   */
  onVisibilityChange: func,

  /**
   * Whether or not the calendar selected date(s) can be cleared.
   */
  allowClear: bool,

  /**
   * The minimum (inclusive) date available for selection.
   */
  minDate: momentType,

  /**
   * The maximum (inclusive) date available for selection.
   */
  maxDate: momentType,

  /**
   * An initial visible month displayed when the calendar open.
   */
  initialVisibleMonth: oneOfType([momentType, func]),

  /**
   * The number of months displayed simultaneously in the calendar.
   */
  numberOfMonths: number,

  /**
   * A React component that display the currently applied date and open the calendar.
   */
  input: element,

  /**
   * The placeholder text.
   */
  placeholder: string,

  /**
   * A format to display a date.
   */
  dateFormat: string,

  /**
   * Whether or not the calendar will open upward.
   */
  upward: bool,

  /**
   * A calendar can open to the left or to the right.
   */
  direction: oneOf(["left", "right"]),

  /**
   * Disables automatic repositioning of the calendar, it will always be placed according to upward and direction values.
   */
  pinned: bool,

  /**
   * z-index of the calendar.
   */
  zIndex: number,

  /**
   * A React component to select a date.
   */
  calendar: element,

  /**
   * A React component displayed under the calendar to `clear` and `apply` the date(s).
   */
  buttons: element,

  /**
   * A controlled open value that determined whether or not the calendar is displayed.
   */
  open: bool,

  /**
   * The initial value of open.
   */
  defaultOpen: bool,

  /**
   * Whether or not the input appear as focused.
   */
  focus: bool,

  /**
   * @ignore
   */
  className: string
}; // Duplicated here until https://github.com/reactjs/react-docgen/pull/352 is merged. Otherwise the props will not render properly in the docs.

const SINGLE_DATE_PICKER_DEFAULT_PROPS = {
  allowClear: true,
  dateFormat: "MMM Do YYYY",
  numberOfMonths: 1,
  calendar: /*#__PURE__*/React.createElement(SingleDatePickerCalendar, null),
  buttons: /*#__PURE__*/React.createElement(SingleDatePickerButtons, null)
};
export class InlineSingleDatePicker extends PureComponent {
  // Expose sub-components.
  render() {
    const _this$props = this.props,
          {
      size
    } = _this$props,
          rest = _objectWithoutProperties(_this$props, ["size"]);

    if (!isNil(size)) {
      throw new Error("".concat(InlineSingleDatePicker.name, " doesn't support the \"size\" prop."));
    }

    return /*#__PURE__*/React.createElement(SingleDatePicker, rest);
  }

}
InlineSingleDatePicker.displayName = "InlineSingleDatePicker";
InlineSingleDatePicker.propTypes = SINGLE_DATE_PICKER_PROP_TYPES;
InlineSingleDatePicker.defaultProps = _objectSpread({
  input: /*#__PURE__*/React.createElement(InlineSingleDatePickerInput, null),
  placeholder: "pick a date"
}, SINGLE_DATE_PICKER_DEFAULT_PROPS);
InlineSingleDatePicker.Input = InlineSingleDatePickerInput;
InlineSingleDatePicker.Calendar = SingleDatePickerCalendar;
InlineSingleDatePicker.Buttons = SingleDatePickerButtons;