import React from "react";
import { AbsoluteRedBox } from "./absolute-red-box";
import { DEFAULT_DATE } from "./data";
import { InlineSingleDatePicker } from "@react-components/date-picker";
import { createChromaticSection, paramsBuilder, storiesOfBuilder } from "@utils";
import { noop } from "lodash";
import moment from "moment";

function stories(segment) {
  return storiesOfBuilder(module, createChromaticSection("DatePicker/single inlined")).segment(segment).parameters(paramsBuilder().canvasLayout({
    width: "80%",
    height: "600px"
  }).chromaticDelay(100).chromaticPauseAnimationAtEnd().build()).build();
}

function createInlineSingleDatePicker(props = {}) {
  return /*#__PURE__*/React.createElement(InlineSingleDatePicker, Object.assign({
    onDateChange: noop
  }, props));
}

createInlineSingleDatePicker.displayName = "createInlineSingleDatePicker";
stories().add("opened", () => createInlineSingleDatePicker({
  initialVisibleMonth: moment(DEFAULT_DATE),
  defaultOpen: true
})).add("default opened", () => createInlineSingleDatePicker({
  initialVisibleMonth: moment(DEFAULT_DATE),
  defaultOpen: true
})).add("closed", () => createInlineSingleDatePicker());
stories("/selected date/closed").add("no selection", () => createInlineSingleDatePicker()).add("date selected", () => createInlineSingleDatePicker({
  date: moment(DEFAULT_DATE)
})).add("null value", () => createInlineSingleDatePicker({
  date: null
}));
stories("/selected date/opened").add("no selection", () => createInlineSingleDatePicker({
  initialVisibleMonth: moment(DEFAULT_DATE),
  defaultOpen: true
})).add("date selected", () => createInlineSingleDatePicker({
  date: moment(DEFAULT_DATE),
  defaultOpen: true
})).add("null value", () => createInlineSingleDatePicker({
  date: null,
  initialVisibleMonth: moment(DEFAULT_DATE),
  defaultOpen: true
}));
stories("/disabled").add("default", () => createInlineSingleDatePicker({
  disabled: true
})).add("selected date", () => createInlineSingleDatePicker({
  defaultDate: moment(DEFAULT_DATE),
  disabled: true
}));
stories("/customization").add("placeholder", () => createInlineSingleDatePicker({
  placeholder: "Custom placeholder"
})).add("date format", () => createInlineSingleDatePicker({
  date: moment(DEFAULT_DATE),
  dateFormat: "YYYY MMM Do"
})).add("styling", () => /*#__PURE__*/React.createElement("div", {
  className: "flex"
}, createInlineSingleDatePicker({
  className: "bg-red mr5"
}), createInlineSingleDatePicker({
  style: {
    backgroundColor: "red"
  }
})));
stories("/z-index").add("over regular text", () => /*#__PURE__*/React.createElement("div", null, createInlineSingleDatePicker({
  initialVisibleMonth: moment(DEFAULT_DATE),
  defaultOpen: true
}), /*#__PURE__*/React.createElement("p", null, "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque vestibulum et"), /*#__PURE__*/React.createElement("p", null, "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque vestibulum et"), /*#__PURE__*/React.createElement("p", null, "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque vestibulum et"), /*#__PURE__*/React.createElement("p", null, "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque vestibulum et"), /*#__PURE__*/React.createElement("p", null, "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque vestibulum et"), /*#__PURE__*/React.createElement("p", null, "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque vestibulum et"), /*#__PURE__*/React.createElement("p", null, "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque vestibulum et"), /*#__PURE__*/React.createElement("p", null, "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque vestibulum et"), /*#__PURE__*/React.createElement("p", null, "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque vestibulum et"))).add("over an element with a z-index greater than 1 but smaller than the date picker", () => /*#__PURE__*/React.createElement("div", null, createInlineSingleDatePicker({
  initialVisibleMonth: moment(DEFAULT_DATE),
  defaultOpen: true
}), /*#__PURE__*/React.createElement("p", null, "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque vestibulum et"), /*#__PURE__*/React.createElement("p", null, "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque vestibulum et"), /*#__PURE__*/React.createElement(AbsoluteRedBox, {
  style: {
    zIndex: 2
  }
}), /*#__PURE__*/React.createElement("p", null, "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque vestibulum et"), /*#__PURE__*/React.createElement("p", null, "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque vestibulum et"), /*#__PURE__*/React.createElement("p", null, "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque vestibulum et"), /*#__PURE__*/React.createElement("p", null, "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque vestibulum et"), /*#__PURE__*/React.createElement("p", null, "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque vestibulum et"))).add("over an element with a z-index greater than the date picker", () => /*#__PURE__*/React.createElement("div", null, createInlineSingleDatePicker({
  initialVisibleMonth: moment(DEFAULT_DATE),
  defaultOpen: true,
  zIndex: 1
}), /*#__PURE__*/React.createElement("p", null, "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque vestibulum et"), /*#__PURE__*/React.createElement("p", null, "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque vestibulum et"), /*#__PURE__*/React.createElement(AbsoluteRedBox, {
  style: {
    zIndex: 2
  }
}), /*#__PURE__*/React.createElement("p", null, "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque vestibulum et"), /*#__PURE__*/React.createElement("p", null, "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque vestibulum et"), /*#__PURE__*/React.createElement("p", null, "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque vestibulum et"), /*#__PURE__*/React.createElement("p", null, "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque vestibulum et"), /*#__PURE__*/React.createElement("p", null, "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque vestibulum et")));
stories("/font-size").add("default", () => createInlineSingleDatePicker()).add("adjust to block font-size", () => /*#__PURE__*/React.createElement("div", {
  className: "f9"
}, /*#__PURE__*/React.createElement("p", null, "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque vestibulum et ", createInlineSingleDatePicker()), /*#__PURE__*/React.createElement("p", null, "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque vestibulum et")));