import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from "react";
import "./Dropdown.css";
import { DropdownButtonItem } from "./DropdownButtonItem";
import { DropdownContext } from "./DropdownContext";
import { DropdownDivider } from "./DropdownDivider";
import { DropdownHeader } from "./DropdownHeader";
import { DropdownItem } from "./DropdownItem";
import { DropdownLinkItem } from "./DropdownLinkItem";
import { DropdownMenu, createDropdownMenu } from "./DropdownMenu";
import { DropdownTitleTrigger } from "./DropdownTitleTrigger";
import { KEYS, augmentElement, resolvePopperPosition, useChainedEventCallback, useEventCallback } from "../../shared";
import { bool, element, func, number, object, oneOf, oneOfType, string } from "prop-types";
import { forwardRef, useState } from "react";
import { isNil } from "lodash";
import { useAutoControlledPopper } from "../../popper";
const propTypes = {
  /**
   * A controlled open value that determined whether or not the menu is displayed.
   */
  open: bool,

  /**
   * The initial value of open.
   */
  defaultOpen: bool,

  /**
   * The default trigger text.
   */
  title: string,

  /**
   * The default trigger icon.
   */
  icon: element,

  /**
   * A custom element to trigger the visibility of the menu. When specified, will have precedence over the the title prop.
   */
  trigger: element,

  /**
   * A dropdown can vary in size.
   */
  size: oneOf(["small", "large"]),

  /**
   * A dropdown menu can open upward.
   */
  upward: bool,

  /**
   * A dropdown menu can open to the left or to the right.
   */
  direction: oneOf(["left", "right"]),

  /**
   * When true, disables automatic repositioning of the component, it will always be placed according to the position value.
   */
  pinned: bool,

  /**
   * z-index of the dropdown menu.
   */
  zIndex: number,

  /**
   * Whether or not the trigger will be rendered as fluid.
   */
  fluid: bool,

  /**
   * A dropdown can have its menu scroll.
   */
  scrolling: bool,

  /**
   * Called when the dropdown open / close.
   * @param {SyntheticEvent} event - React's original SyntheticEvent.
   * @param {boolean} isVisible - Indicate if the dropdown menu is visible.
   * @returns {void}
   */
  onVisibilityChange: func,

  /**
   * [Shorthand](/?path=/docs/getting-started-shorthand-props--page) for the dropdown menu.
   */
  menu: oneOfType([element, object])
};
const defaultProps = {
  direction: "right",
  menu: DropdownMenu
};

function throwWhenMutuallyExclusivePropsAreProvided({
  title,
  trigger
}) {
  if (!isNil(title) && !isNil(trigger)) {
    throw new Error("Dropdown - \"title\" and \"trigger\" props cannot be both specified.");
  }
}

function resolveTrigger(title, icon, trigger) {
  return !isNil(title) ? /*#__PURE__*/React.createElement(DropdownTitleTrigger, {
    title: title,
    icon: icon
  }) : trigger;
}

export function InnerDropdown(props) {
  const {
    open,
    defaultOpen,
    title,
    icon,
    trigger,
    size,
    upward,
    direction,
    pinned,
    zIndex,
    fluid,
    scrolling,
    onVisibilityChange,
    menu,
    active,
    focus,
    hover,
    children,
    forwardedRef
  } = props,
        rest = _objectWithoutProperties(props, ["open", "defaultOpen", "title", "icon", "trigger", "size", "upward", "direction", "pinned", "zIndex", "fluid", "scrolling", "onVisibilityChange", "menu", "active", "focus", "hover", "children", "forwardedRef"]);

  throwWhenMutuallyExclusivePropsAreProvided(props);
  const [isOpen, setIsOpen] = useState();
  const handleVisibilityChange = useChainedEventCallback(onVisibilityChange, (event, isVisible) => {
    setIsOpen(isVisible);
  });
  const dropdownTrigger = augmentElement(resolveTrigger(title, icon, trigger), _objectSpread({
    size,
    fluid,
    active,
    focus,
    hover
  }, rest));
  const {
    renderPopper,
    hidePopper: closePopper,
    focusTrigger
  } = useAutoControlledPopper({
    show: open,
    defaultShow: defaultOpen,
    trigger: dropdownTrigger,
    toggleHandler: "onClick",
    position: resolvePopperPosition(upward, direction),
    pinned,
    offset: [0, 10],
    zIndex,
    fluid,
    showOnKeys: [upward ? KEYS.up : KEYS.down],
    focusFirstElementOnKeyboardShow: true,
    onVisibilityChange: handleVisibilityChange,
    popper: {
      className: "o-ui dropdown"
    }
  });
  const handleSelectItem = useEventCallback(event => {
    // HACK: anchors were not activated on enter keydown, delaying close fix it.
    setTimeout(() => {
      closePopper(event);
      focusTrigger();
    }, 0);
  });
  const dropdownMenu = createDropdownMenu(menu, {
    scrolling,
    fluid,
    onSelectItem: handleSelectItem,
    children,
    ref: forwardedRef
  });
  return /*#__PURE__*/React.createElement(DropdownContext.Provider, {
    value: {
      isOpen,
      size,
      upward,
      direction
    }
  }, renderPopper(dropdownMenu));
}
InnerDropdown.displayName = "InnerDropdown";
InnerDropdown.propTypes = propTypes;
InnerDropdown.defaultProps = defaultProps;
export const Dropdown = /*#__PURE__*/forwardRef((props, ref) => /*#__PURE__*/React.createElement(InnerDropdown, Object.assign({}, props, {
  forwardedRef: ref
})));
[InnerDropdown, Dropdown].forEach(x => {
  x.Menu = DropdownMenu;
  x.Item = DropdownItem;
  x.LinkItem = DropdownLinkItem;
  x.ButtonItem = DropdownButtonItem;
  x.Header = DropdownHeader;
  x.Divider = DropdownDivider;
  x.DropdownTitleTrigger = DropdownTitleTrigger;
});