import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import React from "react";
import { DropdownContext } from "./DropdownContext";
import { DropdownMenuContext } from "./DropdownMenuContext";
import { EmbeddedIcon } from "../../icons";
import { Dropdown as SemanticDropdown } from "semantic-ui-react";
import { SemanticRef, mergeClasses, throwWhenUnsupportedPropIsProvided, useChainedEventCallback } from "../../shared";
import { element, string } from "prop-types";
import { forwardRef, useContext } from "react";
import { isNil } from "lodash";
const UNSUPPORTED_PROPS = ["flag", "image", "label"];
const propTypes = {
  /**
   * The item text.
   */
  text: string,

  /**
   * The item value.
   */
  value: string,

  /**
   * An item can navigate to a page.
   */
  href: string,

  /**
   * A description to display with less emphasize.
   */
  description: string,

  /**
   * [Shorthand](/?path=/docs/getting-started-shorthand-props--page) to display an [icon](/?path=/docs/components-icon--default-story) before the text.
   */
  icon: element
};
export function InnerDropdownItem(props) {
  const {
    text: legacyText,
    icon,
    description,
    onClick,
    focus,
    hover,
    children,
    forwardedRef
  } = props,
        rest = _objectWithoutProperties(props, ["text", "icon", "description", "onClick", "focus", "hover", "children", "forwardedRef"]);

  const {
    size
  } = useContext(DropdownContext);
  const {
    onItemClick
  } = useContext(DropdownMenuContext);
  throwWhenUnsupportedPropIsProvided(props, UNSUPPORTED_PROPS, "@orbit-ui/react-components/DropdownItem");
  const handleClick = useChainedEventCallback(onClick, onItemClick);
  const text = legacyText || children;
  const iconMarkup = !isNil(icon) && /*#__PURE__*/React.createElement(EmbeddedIcon, {
    icon: icon,
    size: size
  });
  const textMarkup = !isNil(text) && /*#__PURE__*/React.createElement("span", {
    className: "text"
  }, text);
  const descriptionMarkup = !isNil(description) && /*#__PURE__*/React.createElement("span", {
    className: "description"
  }, children);
  const content = /*#__PURE__*/React.createElement(React.Fragment, null, iconMarkup, textMarkup, descriptionMarkup);
  return /*#__PURE__*/React.createElement(SemanticRef, {
    innerRef: forwardedRef
  }, /*#__PURE__*/React.createElement(SemanticDropdown.Item, Object.assign({}, rest, {
    onClick: handleClick,
    className: mergeClasses(focus && "focus", hover && "hover"),
    tabIndex: "-1"
  }), content));
}
InnerDropdownItem.displayName = "InnerDropdownItem";
InnerDropdownItem.propTypes = propTypes;
export const DropdownItem = /*#__PURE__*/forwardRef((props, ref) => /*#__PURE__*/React.createElement(InnerDropdownItem, Object.assign({}, props, {
  forwardedRef: ref
})));