import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import React from "react";
import { Button } from "@react-components/button";
import { Dropdown } from "@react-components/dropdown";
import { createRef, forwardRef } from "react";
import { render, waitFor } from "@testing-library/react";
const SimpleDropdown = /*#__PURE__*/forwardRef((_ref, ref) => {
  let {
    title = "File"
  } = _ref,
      rest = _objectWithoutProperties(_ref, ["title"]);

  return /*#__PURE__*/React.createElement(Dropdown, Object.assign({}, rest, {
    title: title,
    ref: ref
  }), /*#__PURE__*/React.createElement(Dropdown.Item, null, "New"), /*#__PURE__*/React.createElement(Dropdown.Item, null, "Open..."), /*#__PURE__*/React.createElement(Dropdown.Item, null, "Save as..."));
});
const TriggerLessDropdown = /*#__PURE__*/forwardRef((props, ref) => {
  return /*#__PURE__*/React.createElement(Dropdown, Object.assign({}, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement(Dropdown.Item, null, "New"), /*#__PURE__*/React.createElement(Dropdown.Item, null, "Open..."), /*#__PURE__*/React.createElement(Dropdown.Item, null, "Save as..."));
}); // ***** API *****

test("spread additional props on the trigger element", async () => {
  const ref = /*#__PURE__*/createRef();
  render( /*#__PURE__*/React.createElement(TriggerLessDropdown, {
    trigger: /*#__PURE__*/React.createElement(Button, {
      ref: ref
    }, "Click me"),
    "data-extra-props-test": "works"
  }));
  await waitFor(() => expect(ref.current.getAttribute("data-extra-props-test")).toBe("works"));
}); // ***** Refs *****

test("ref is a DOM element", async () => {
  const ref = /*#__PURE__*/createRef();
  render( /*#__PURE__*/React.createElement(SimpleDropdown, {
    ref: ref,
    open: true
  }));
  await waitFor(() => expect(ref.current).not.toBeNull());
  expect(ref.current instanceof HTMLElement).toBeTruthy();
  expect(ref.current.tagName).toBe("DIV");
});
test("using a callback ref, ref is a DOM element", async () => {
  let refNode = null;
  render( /*#__PURE__*/React.createElement(SimpleDropdown, {
    ref: node => {
      refNode = node;
    },
    open: true
  }));
  await waitFor(() => expect(refNode).not.toBeNull());
  expect(refNode instanceof HTMLElement).toBeTruthy();
  expect(refNode.tagName).toBe("DIV");
});
test("set ref once", async () => {
  const handler = jest.fn();
  render( /*#__PURE__*/React.createElement(SimpleDropdown, {
    ref: handler,
    open: true
  }));
  await waitFor(() => expect(handler).toHaveBeenCalledTimes(1));
});