import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import React from "react";
import { SIZE, mergeClasses } from "../../shared";
import { elementType, oneOf } from "prop-types";
import { forwardRef } from "react";
const SIZES = ["micro", "mini", "tiny", "small", "medium", "large", "big", "huge", "massive"];
const DIMENSION_CLASSES = {
  [SIZE.micro]: "w2 h2",
  [SIZE.mini]: "w3 h3",
  [SIZE.tiny]: "w4 h4",
  [SIZE.small]: "w5 h5",
  [SIZE.medium]: "w6 h6",
  [SIZE.large]: "w7 h7",
  [SIZE.big]: "w8 h8",
  [SIZE.huge]: "w9 h9",
  [SIZE.massive]: "w10 h10"
};
export function InnerIcon(_ref) {
  let {
    type: ComponentType,
    size,
    className,
    forwardedRef
  } = _ref,
      rest = _objectWithoutProperties(_ref, ["type", "size", "className", "forwardedRef"]);

  const classes = mergeClasses("icon", className, DIMENSION_CLASSES[size || SIZE.medium]);
  return /*#__PURE__*/React.createElement(ComponentType, Object.assign({}, rest, {
    className: classes,
    ref: forwardedRef
  }));
}
InnerIcon.displayName = "InnerIcon";
InnerIcon.propTypes = {
  /**
   * An icon as a React component.
   */
  type: elementType.isRequired,

  /**
   * An icon can vary in size.
   */
  size: oneOf(SIZES)
};
export const Icon = /*#__PURE__*/forwardRef((props, ref) => /*#__PURE__*/React.createElement(InnerIcon, Object.assign({}, props, {
  forwardedRef: ref
})));

function createIconFactory(type) {
  return /*#__PURE__*/forwardRef((props, ref) => /*#__PURE__*/React.createElement(Icon, Object.assign({
    type: type,
    ref: ref
  }, props)));
}

[InnerIcon, Icon].forEach(x => {
  x.create = createIconFactory;
}); //////////////////////////////////////////////

export function InnerMultiVariantIcon(_ref2) {
  let {
    type24: Component24,
    type32: Component32,
    size,
    forwardedRef
  } = _ref2,
      rest = _objectWithoutProperties(_ref2, ["type24", "type32", "size", "forwardedRef"]);

  let type = Component32;

  if (size === SIZE.tiny || size === SIZE.small || size === SIZE.medium) {
    type = Component24;
  }

  return /*#__PURE__*/React.createElement(Icon, Object.assign({}, rest, {
    type: type,
    size: size,
    ref: forwardedRef
  }));
}
InnerMultiVariantIcon.displayName = "InnerMultiVariantIcon";
InnerMultiVariantIcon.propTypes = {
  /**
   * An icon as a React component for the 24px variant.
   */
  type24: elementType.isRequired,

  /**
   * An icon as a React component for the 32px variant.
   */
  type32: elementType.isRequired,

  /**
   * An icon can vary in size.
   */
  size: oneOf(SIZES)
};
export const MultiVariantIcon = /*#__PURE__*/forwardRef((props, ref) => /*#__PURE__*/React.createElement(InnerMultiVariantIcon, Object.assign({}, props, {
  forwardedRef: ref
})));

function createMultiVariantFactory(type24, type32) {
  return /*#__PURE__*/forwardRef((props, ref) => /*#__PURE__*/React.createElement(MultiVariantIcon, Object.assign({
    type24: type24,
    type32: type32,
    ref: ref
  }, props)));
}

[InnerMultiVariantIcon, MultiVariantIcon].forEach(x => {
  x.create = createMultiVariantFactory;
});