import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import React from "react";
import styles from "./Popper.chroma.module.css";
import { Button } from "@react-components/button";
import { Popper } from "@react-components/popper";
import { createChromaticSection, paramsBuilder, storiesOfBuilder } from "@utils";
import { forwardRef, useLayoutEffect, useState } from "react";
import { isNil } from "lodash";
import { useAutoControlledState } from "@react-components/shared";

function stories(segment) {
  return storiesOfBuilder(module, createChromaticSection("Popper/popper")).segment(segment).parameters(paramsBuilder().canvasLayout({
    width: "30%",
    height: "600px",
    marginTop: "100px"
  }).chromaticDelay(100).chromaticPauseAnimationAtEnd().build()).build();
}

const RedBox = /*#__PURE__*/forwardRef((props, ref) => {
  return /*#__PURE__*/React.createElement("div", Object.assign({}, props, {
    className: "w12 h12 bg-red",
    tabIndex: "0",
    ref: ref
  }));
});
const RedBoxPopper = /*#__PURE__*/forwardRef((_ref, ref) => {
  let {
    show,
    defaultShow
  } = _ref,
      rest = _objectWithoutProperties(_ref, ["show", "defaultShow"]);

  const [triggerElement, setTriggerElement] = useState();
  const [isVisible, setIsVisible] = useAutoControlledState(show, defaultShow, false);
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Button, {
    fluid: true,
    onClick: () => setIsVisible(!isVisible),
    ref: setTriggerElement
  }, "Open"), !isNil(triggerElement) ? /*#__PURE__*/React.createElement(Popper, Object.assign({
    show: isVisible,
    triggerElement: triggerElement,
    ref: ref
  }, rest), /*#__PURE__*/React.createElement(RedBox, null)) : null);
});

function BoundedRedBoxPopper(_ref2) {
  let {
    scrollTop = 0,
    setPreventOverflowBoundaryElement,
    setFlipBoundaryElement
  } = _ref2,
      rest = _objectWithoutProperties(_ref2, ["scrollTop", "setPreventOverflowBoundaryElement", "setFlipBoundaryElement"]);

  const [boundaryElement, setBoundaryElement] = useState();

  const createModifier = name => {
    return {
      name,
      options: {
        boundary: boundaryElement
      }
    };
  };

  useLayoutEffect(() => {
    if (!isNil(boundaryElement)) {
      boundaryElement.scrollTop = scrollTop;
    }
  }, [boundaryElement, scrollTop]);

  const createModifiers = () => {
    const modifiers = [];

    if (setPreventOverflowBoundaryElement) {
      modifiers.push(createModifier("preventOverflow"));
    }

    if (setFlipBoundaryElement) {
      modifiers.push(createModifier("flip"));
    }

    return modifiers;
  };

  return /*#__PURE__*/React.createElement("div", {
    className: styles.boundary,
    ref: setBoundaryElement
  }, /*#__PURE__*/React.createElement(RedBoxPopper, Object.assign({
    show: true,
    popperModifiers: createModifiers()
  }, rest)));
}

BoundedRedBoxPopper.displayName = "BoundedRedBoxPopper";
stories().add("default", () => /*#__PURE__*/React.createElement(RedBoxPopper, null)).add("show", () => /*#__PURE__*/React.createElement(RedBoxPopper, {
  show: true
})).add("default show", () => /*#__PURE__*/React.createElement(RedBoxPopper, {
  defaultShow: true
})).add("position auto", () => /*#__PURE__*/React.createElement(RedBoxPopper, {
  show: true,
  position: "auto"
})).add("position auto-start", () => /*#__PURE__*/React.createElement(RedBoxPopper, {
  show: true,
  position: "auto-start"
})).add("position auto-end", () => /*#__PURE__*/React.createElement(RedBoxPopper, {
  show: true,
  position: "auto-end"
})).add("position top", () => /*#__PURE__*/React.createElement(RedBoxPopper, {
  show: true,
  position: "top",
  pinned: true
})).add("position top-start", () => /*#__PURE__*/React.createElement(RedBoxPopper, {
  show: true,
  position: "top-start",
  pinned: true
})).add("position top-end", () => /*#__PURE__*/React.createElement(RedBoxPopper, {
  show: true,
  position: "top-end",
  pinned: true
})).add("position bottom", () => /*#__PURE__*/React.createElement(RedBoxPopper, {
  show: true,
  position: "bottom",
  pinned: true
})).add("position bottom-end", () => /*#__PURE__*/React.createElement(RedBoxPopper, {
  show: true,
  position: "bottom-end",
  pinned: true
})).add("position bottom-start", () => /*#__PURE__*/React.createElement(RedBoxPopper, {
  show: true,
  position: "bottom-start",
  pinned: true
})).add("position right", () => /*#__PURE__*/React.createElement(RedBoxPopper, {
  show: true,
  position: "right",
  pinned: true
})).add("position right", () => /*#__PURE__*/React.createElement(RedBoxPopper, {
  show: true,
  position: "right",
  pinned: true
})).add("position right-start", () => /*#__PURE__*/React.createElement(RedBoxPopper, {
  show: true,
  position: "right-start",
  pinned: true
})).add("position right-end", () => /*#__PURE__*/React.createElement(RedBoxPopper, {
  show: true,
  position: "right-end",
  pinned: true
})).add("position left", () => /*#__PURE__*/React.createElement(RedBoxPopper, {
  show: true,
  position: "left",
  pinned: true
})).add("position left-start", () => /*#__PURE__*/React.createElement(RedBoxPopper, {
  show: true,
  position: "left-start",
  pinned: true
})).add("position left-end", () => /*#__PURE__*/React.createElement(RedBoxPopper, {
  show: true,
  position: "left-end",
  pinned: true
})).add("fixed positioning", () => /*#__PURE__*/React.createElement(RedBoxPopper, {
  show: true,
  popperOptions: {
    strategy: "fixed"
  }
})).add("no portal", () => /*#__PURE__*/React.createElement("div", {
  className: "flex flex-column"
}, /*#__PURE__*/React.createElement("div", {
  style: {
    marginBottom: "100px"
  }
}, /*#__PURE__*/React.createElement(RedBoxPopper, {
  noPortal: true
})), /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(RedBoxPopper, {
  show: true,
  noPortal: true
})))).add("custom portal container element", () => /*#__PURE__*/React.createElement(RedBoxPopper, {
  show: true,
  portalContainerElement: window.document.getElementById("root")
})).add("no wrap", () => /*#__PURE__*/React.createElement(RedBoxPopper, {
  show: true,
  noWrap: true
})).add("no animation", () => /*#__PURE__*/React.createElement(RedBoxPopper, {
  show: true,
  animate: false
})).add("styling", () => /*#__PURE__*/React.createElement("div", {
  className: "flex flex-column"
}, /*#__PURE__*/React.createElement("div", {
  style: {
    marginBottom: "100px"
  }
}, /*#__PURE__*/React.createElement(RedBoxPopper, {
  show: true,
  className: "border-blue"
})), /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(RedBoxPopper, {
  show: true,
  style: {
    border: "1px solid blue"
  }
})))).add("can prevent overflow when not pinned", () => /*#__PURE__*/React.createElement(BoundedRedBoxPopper, {
  position: "right",
  noPortal: true,
  scrollTop: 100,
  setPreventOverflowBoundaryElement: true
}), paramsBuilder().canvasLayout({
  width: "40%"
}).build()).add("do not prevent overflow when pinned", () => /*#__PURE__*/React.createElement(BoundedRedBoxPopper, {
  position: "right",
  noPortal: true,
  scrollTop: 100,
  pinned: true
}), paramsBuilder().canvasLayout({
  width: "40%"
}).build()).add("can flip", () => /*#__PURE__*/React.createElement(BoundedRedBoxPopper, {
  position: "top",
  noPortal: true,
  scrollTop: 100,
  setFlipBoundaryElement: true
})).add("do not flip when pinned", () => /*#__PURE__*/React.createElement(BoundedRedBoxPopper, {
  position: "top",
  noPortal: true,
  scrollTop: 100,
  pinned: true
})).add("disabled", () => /*#__PURE__*/React.createElement(RedBoxPopper, {
  disabled: true
}));
stories("/offsets/bottom").add("left+positive", () => /*#__PURE__*/React.createElement(RedBoxPopper, {
  position: "bottom-end",
  offset: [30, 30],
  show: true
})).add("left+negative", () => /*#__PURE__*/React.createElement(RedBoxPopper, {
  position: "bottom-end",
  offset: [-30, -30],
  show: true
})).add("right+positive", () => /*#__PURE__*/React.createElement(RedBoxPopper, {
  position: "bottom-start",
  offset: [30, 30],
  show: true
})).add("right+negative", () => /*#__PURE__*/React.createElement(RedBoxPopper, {
  position: "bottom-start",
  offset: [-30, -30],
  show: true
}));
stories("/offsets/top").add("left+positive", () => /*#__PURE__*/React.createElement(RedBoxPopper, {
  position: "top-end",
  offset: [30, 30],
  show: true
}), paramsBuilder().canvasLayout({
  marginTop: "150px"
}).build()).add("left+negative", () => /*#__PURE__*/React.createElement(RedBoxPopper, {
  position: "top-end",
  offset: [-30, -30],
  show: true
}), paramsBuilder().canvasLayout({
  marginTop: "150px"
}).build()).add("right+positive", () => /*#__PURE__*/React.createElement(RedBoxPopper, {
  position: "top-start",
  offset: [30, 30],
  show: true
}), paramsBuilder().canvasLayout({
  marginTop: "150px"
}).build()).add("right+negative", () => /*#__PURE__*/React.createElement(RedBoxPopper, {
  position: "top-start",
  offset: [-30, -30],
  show: true
}), paramsBuilder().canvasLayout({
  marginTop: "150px"
}).build());