import React from "react";
import { KEYS } from "../../shared";
import { SelectContext } from "./SelectContext";
import { Dropdown as SemanticDropdown } from "semantic-ui-react";
import { isNil } from "lodash";
import { renderAvatar } from "./renderAvatar";
import { renderIcons } from "./renderIcons";
import cx from "classnames";
export class MonkeyPatchSemanticDropdown extends SemanticDropdown {
  constructor(...args) {
    super(...args);

    this.openOnSpace = event => {
      const key = event.keyCode; // HACK: don't open on spacebar keydown since the Select component will take care of it.

      if (key === KEYS.space) {
        event.preventDefault();
        this.open(event);
      }
    };

    this.renderAvatarResult = ({
      text,
      avatar
    }) => {
      const {
        inline
      } = this.props;
      const {
        size
      } = this.context;
      return /*#__PURE__*/React.createElement(React.Fragment, null, renderAvatar(avatar, !inline ? size : undefined), text);
    };

    this.renderIconsResult = ({
      text,
      icons,
      iconsPosition
    }) => {
      const {
        inline
      } = this.props;
      const {
        size
      } = this.context;
      let left = null;
      let right = null;
      let renderedIcons = renderIcons(icons, size);

      if (inline) {
        renderedIcons = /*#__PURE__*/React.createElement("span", {
          className: iconsPosition === "right" ? "fr" : "fl"
        }, renderedIcons);
      }

      if (iconsPosition === "right") {
        right = renderedIcons;
      } else {
        left = renderedIcons;
      }

      return /*#__PURE__*/React.createElement(React.Fragment, null, !isNil(left) && left, /*#__PURE__*/React.createElement("span", {
        className: "mr1"
      }, text), !isNil(right) && right);
    };

    this.renderCustomResult = item => {
      const {
        text,
        avatar,
        icons
      } = item;

      if (!isNil(avatar)) {
        return this.renderAvatarResult(item);
      } else if (!isNil(icons)) {
        return this.renderIconsResult(item);
      }

      return text;
    };

    this.renderText = () => {
      const {
        multiple,
        placeholder,
        search,
        text
      } = this.props;
      const {
        searchQuery,
        value,
        open,
        focus
      } = this.state;
      let result = placeholder;
      const hasValue = this.hasValue();

      if (!isNil(text)) {
        result = text;
      } else if (!multiple) {
        if (open && focus) {
          const item = this.getSelectedItem();

          if (!isNil(item)) {
            if (!search) {
              result = this.renderCustomResult(item);
            } else {
              result = item.text;
            }
          }
        } else if (hasValue) {
          const item = this.getItemByValue(value);

          if (!isNil(item)) {
            if (!search || !focus) {
              result = this.renderCustomResult(item);
            } else {
              result = item.text;
            }
          }
        }
      }

      const classes = cx(placeholder && !hasValue && "default", "text", search && searchQuery && "filtered");
      return /*#__PURE__*/React.createElement("div", {
        className: classes,
        role: "alert",
        "aria-live": "polite",
        "aria-atomic": true
      }, result);
    };

    this.closeOnEscape = event => {
      const {
        closeOnEscape
      } = this.props;

      if (closeOnEscape) {
        if (event.keyCode === KEYS.esc) {
          event.preventDefault();
          this.close(event);
          setTimeout(() => {
            if (!isNil(this.ref.current)) {
              this.ref.current.focus();
            }
          }, 0);
        }
      }
    };
  }

}
MonkeyPatchSemanticDropdown.contextType = SelectContext;