import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import React from "react";
import { SIZE, SemanticRef, createShorthandFactory, createShorthandFactoryForEmbedded, mergeClasses, throwWhenUnsupportedPropIsProvided } from "../../shared";
import { Label as SemanticLabel } from "semantic-ui-react";
import { forwardRef } from "react";
import { isString } from "lodash";
import { oneOf } from "prop-types";
const UNSUPPORTED_PROPS = ["attached", "color", "circular", "corner", "floating", "horizontal", "image", "onClick", "onRemove", "pointing", "prompt", "removeIcon", "ribbon", "tag"];
const propTypes = {
  /**
   * A tag can vary in sizes.
   */
  size: oneOf(["micro", "mini", "tiny", "small", "medium", "large", "big", "huge", "massive"])
};
export function InnerTag(_ref) {
  let {
    forwardedRef,
    className,
    disabled
  } = _ref,
      props = _objectWithoutProperties(_ref, ["forwardedRef", "className", "disabled"]);

  throwWhenUnsupportedPropIsProvided(props, UNSUPPORTED_PROPS, "@orbit-ui/react-components/Tag");
  return /*#__PURE__*/React.createElement(SemanticRef, {
    innerRef: forwardedRef
  }, /*#__PURE__*/React.createElement(SemanticLabel, Object.assign({}, props, {
    tag: true,
    circular: true,
    empty: true,
    className: mergeClasses(disabled && "disabled", className)
  })));
}
InnerTag.displayName = "InnerTag";
InnerTag.propTypes = propTypes;
export const Tag = /*#__PURE__*/forwardRef((props, ref) => /*#__PURE__*/React.createElement(InnerTag, Object.assign({}, props, {
  forwardedRef: ref
})));
export const createTag = createShorthandFactory(Tag, (shorthand, props) => {
  if (isString(shorthand)) {
    return /*#__PURE__*/React.createElement(Tag, Object.assign({}, props, {
      className: shorthand
    }));
  }
});
export const createEmbeddedTag = createShorthandFactoryForEmbedded(createTag, {
  [SIZE.micro]: SIZE.micro,
  [SIZE.mini]: SIZE.micro,
  [SIZE.tiny]: SIZE.micro,
  [SIZE.small]: SIZE.mini,
  [SIZE.medium]: SIZE.mini,
  [SIZE.large]: SIZE.tiny
});