import React from "react";
import { CloseIcon } from "../../icons";
import { Label } from "../../label";
import { PureComponent } from "react";
import { SIZE, mergeClasses } from "../../shared";
import { arrayOf, func, oneOf, shape, string } from "prop-types"; // Duplicated here until https://github.com/reactjs/react-docgen/pull/352 is merged. Otherwise the props will not render properly in the docs.

const ITEM_SHAPE = {
  text: string.isRequired,
  value: string.isRequired
}; // Sizes constants are duplicated here until https://github.com/reactjs/react-docgen/pull/352 is merged. Otherwise it will not render properly in the docs.

const SIZES = ["small", "medium", "large"];

function defaultItemRenderer(item, {
  disabled,
  size,
  onRemove
}) {
  return /*#__PURE__*/React.createElement(Label, {
    basic: true,
    size: size,
    button: !disabled ? {
      icon: /*#__PURE__*/React.createElement(CloseIcon, null),
      onClick: onRemove
    } : undefined
  }, item.text);
}

defaultItemRenderer.displayName = "defaultItemRenderer";

class TagsPickerSelectedItem extends PureComponent {
  constructor(...args) {
    super(...args);

    this.handleRemove = event => {
      const {
        item,
        onRemove
      } = this.props;
      onRemove(event, item);
    };
  }

  render() {
    const {
      item,
      itemRenderer,
      disabled,
      size,
      className
    } = this.props;
    const classes = mergeClasses("mr2 mb2", className);
    return /*#__PURE__*/React.createElement("div", {
      className: classes
    }, itemRenderer(item, {
      disabled,
      size,
      onRemove: this.handleRemove
    }));
  }

}

TagsPickerSelectedItem.displayName = "TagsPickerSelectedItem";
TagsPickerSelectedItem.propTypes = {
  item: shape(ITEM_SHAPE).isRequired,
  itemRenderer: func,
  onRemove: func.isRequired,
  size: oneOf([SIZE.small, SIZE.medium, SIZE.large]),
  className: string
};
export class TagsPickerSelectedItems extends PureComponent {
  constructor(...args) {
    super(...args);

    this.handleRemoveSelectedItem = (event, item) => {
      const {
        onRemoveSelectedItem
      } = this.props;
      onRemoveSelectedItem(event, item);
    };
  }

  renderItems() {
    const {
      items,
      itemRenderer,
      disabled,
      size,
      className
    } = this.props;
    return items.map(x => {
      return /*#__PURE__*/React.createElement(TagsPickerSelectedItem, {
        item: x,
        itemRenderer: itemRenderer,
        onRemove: this.handleRemoveSelectedItem,
        key: x.value,
        disabled: disabled,
        size: size,
        className: className
      });
    });
  }

  render() {
    const {
      items
    } = this.props;

    if (items.length === 0) {
      return null;
    }

    return /*#__PURE__*/React.createElement(React.Fragment, null, this.renderItems());
  }

}
TagsPickerSelectedItems.displayName = "TagsPickerSelectedItems";
TagsPickerSelectedItems.propTypes = {
  /**
   * Items to display.
   */
  items: arrayOf(shape(ITEM_SHAPE)),

  /**
   * Render an item.
   * @param {Item} item - Item to render.
   * @param {{ disabled: boolean, onRemove: function }} options - Rendering options.
   * @returns {ReactElement} - React element to render.
   */
  itemRenderer: func,

  /**
   * Called when an item is removed.
   * @param {SyntheticEvent} event - React's original SyntheticEvent.
   * @param {Item} item - Removed item.
   * @param {Object} props - All the props.
   * @returns {void}
   */
  onRemoveSelectedItem: func,

  /**
   * A selected item can have different sizes.
   */
  size: oneOf(SIZES)
};
TagsPickerSelectedItems.defaultProps = {
  itemRenderer: defaultItemRenderer
};